import React$1, { FormEvent } from 'react';
import { AutocompleteResult, AutocompletedResult, AutocompletedSuggestions, AutocompleteSuggestion, AutocompletedSuggestion, SearchContextState, SearchResult, FieldValue, FacetValue, FilterType } from '@elastic/search-ui';

type SearchBoxAutocompleteViewProps = {
    allAutocompletedItemsCount: number;
    autocompleteResults?: boolean | AutocompleteResult;
    autocompletedResults: AutocompletedResult[];
    autocompletedSuggestions: AutocompletedSuggestions;
    autocompletedSuggestionsCount: number;
    autocompleteSuggestions?: boolean | AutocompleteSuggestion;
    getItemProps: (value: {
        key: string;
        index: number;
        item: AutocompletedSuggestion;
    }) => any;
    getMenuProps: (value: {
        className: string;
    }) => any;
    className?: string;
};
declare function Autocomplete({ autocompleteResults, autocompletedResults, autocompleteSuggestions, autocompletedSuggestions, className, getItemProps, getMenuProps }: SearchBoxAutocompleteViewProps): React$1.JSX.Element;

type PagingContainerContext = Pick<SearchContextState, "current" | "resultsPerPage" | "totalPages" | "setCurrent">;
type PagingViewProps = Rename<BaseContainerProps & PagingContainerContext, {
    setCurrent: "onChange";
}>;
type PagingContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<PagingViewProps>;
};
declare function Paging({ className, current, resultsPerPage, onChange, totalPages, ...rest }: PagingViewProps): React$1.JSX.Element;

type PagingInfoContainerContext = Pick<SearchContextState, "pagingStart" | "pagingEnd" | "resultSearchTerm" | "totalResults">;
type PagingInfoViewProps = Rename<BaseContainerProps & PagingInfoContainerContext, {
    pagingStart: "start";
    resultSearchTerm: "searchTerm";
    pagingEnd: "end";
}>;
type PagingInfoContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<PagingInfoViewProps>;
};
declare function PagingInfo({ className, end, searchTerm, start, totalResults, ...rest }: PagingInfoViewProps & React$1.HTMLAttributes<HTMLDivElement>): React$1.JSX.Element;

type ResultContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<ResultViewProps>;
    clickThroughTags?: string[];
    titleField?: string;
    urlField?: string;
    thumbnailField?: string;
    result: SearchResult;
    shouldTrackClickThrough?: boolean;
};
type ResultViewProps = BaseContainerProps & Pick<ResultContainerProps, "result" | "titleField" | "urlField" | "thumbnailField"> & {
    key?: string;
    onClickLink: () => void;
};
declare function Result({ className, result, onClickLink, titleField, urlField, thumbnailField, ...rest }: ResultViewProps): React$1.JSX.Element;

type ResultsContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<ResultsViewProps>;
    resultView?: React$1.ComponentType<ResultViewProps>;
    clickThroughTags?: string[];
    titleField?: string;
    urlField?: string;
    thumbnailField?: string;
    shouldTrackClickThrough?: boolean;
};
type ResultsViewProps = BaseContainerProps;
declare function Results({ children, className, ...rest }: ResultsViewProps & React$1.HTMLAttributes<HTMLUListElement>): React$1.JSX.Element;

type ResultsPerPageContainerContext = Pick<SearchContextState, "resultsPerPage" | "setResultsPerPage">;
type ResultsPerPageContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<ResultsPerPageViewProps>;
    options?: number[];
};
type ResultsPerPageViewProps = BaseContainerProps & Pick<ResultsPerPageContainerProps, "options"> & Rename<ResultsPerPageContainerContext, {
    setResultsPerPage: "onChange";
    resultsPerPage: "value";
}>;
declare function ResultsPerPage({ className, onChange, options, value: selectedValue, ...rest }: ResultsPerPageViewProps): React$1.JSX.Element;

type SearchBoxContainerContext = Pick<SearchContextState, "autocompletedResults" | "autocompletedSuggestions">;
type SearchBoxContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<SearchBoxViewProps>;
    autocompleteView?: React$1.ComponentType<SearchBoxAutocompleteViewProps>;
    inputView?: React$1.ComponentType<InputViewProps>;
    autocompleteMinimumCharacters?: number;
    autocompleteResults?: AutocompleteResult | boolean;
    autocompleteSuggestions?: boolean | AutocompleteSuggestion;
    shouldClearFilters?: boolean;
    debounceLength?: number;
    inputProps?: any;
    onSelectAutocomplete?: any;
    onSubmit?: (searchTerm: string) => void;
    searchAsYouType?: boolean;
};
type SearchBoxViewProps = BaseContainerProps & SearchBoxContainerContext & Pick<SearchBoxContainerProps, "autocompleteView" | "inputView" | "autocompleteResults" | "autocompleteSuggestions"> & {
    allAutocompletedItemsCount: number;
    autocompletedSuggestionsCount: any;
    completeSuggestion: (searchQuery: string) => void;
    isFocused: boolean;
    notifyAutocompleteSelected: (selection: any) => void;
    onChange: (value: string) => void;
    onSelectAutocomplete: any;
    onSubmit: (e: FormEvent) => void;
    useAutocomplete: boolean;
    value: string;
    inputProps: any;
};
declare function SearchBox(props: SearchBoxViewProps): React$1.JSX.Element;

type InputViewProps = {
    getAutocomplete: () => React$1.JSX.Element;
    getButtonProps: (additionalProps?: any) => any;
    getInputProps: (additionalProps?: any) => any;
};

type SortingViewProps = BaseContainerProps & Pick<SortingContainerProps, "label"> & {
    onChange: (sortData?: any) => void;
    options: {
        value: string;
        label: string;
    }[];
    value: string;
};
type SortingContainerProps = BaseContainerProps & {
    view?: React$1.ComponentType<SortingViewProps>;
    label?: string;
    sortOptions: any;
};
declare function Sorting({ className, label, onChange, options, value, ...rest }: SortingViewProps): React$1.JSX.Element;

interface BaseContainerProps {
    children?: React.ReactNode;
    className?: string;
}

type FacetViewProps = {
    className?: string;
    label: string;
    onMoreClick: () => void;
    onRemove: (value: FieldValue) => void;
    onChange: (value: FieldValue) => void;
    onSelect: (value: FieldValue) => void;
    options: FacetValue[];
    showMore: boolean;
    values: any;
    showSearch: boolean;
    onSearch: (value: string) => void;
    searchPlaceholder: string;
};
type FacetContainerProps = BaseContainerProps & {
    filterType?: FilterType;
    show?: number;
    view?: React.ComponentType<FacetViewProps>;
    isFilterable?: boolean;
    field: string;
    label: string;
    persistent?: boolean;
};
type Rename<T, R extends {
    [K in keyof R]: K extends keyof T ? PropertyKey : "Error: key not in T";
}> = {
    [P in keyof T as P extends keyof R ? R[P] : P]: T[P];
};

type ErrorBoundaryContainerContext = Pick<SearchContextState, "error">;
type ErrorBoundaryViewProps = BaseContainerProps & ErrorBoundaryContainerContext;
declare function ErrorBoundary({ children, className, error, ...rest }: ErrorBoundaryViewProps & React$1.HTMLAttributes<HTMLDivElement>): React$1.JSX.Element;

type FacetsProps = {
    children: React$1.ReactNode;
    className?: string;
} & React$1.HTMLAttributes<HTMLDivElement>;
declare function Facets({ children, className, ...rest }: FacetsProps): React$1.JSX.Element;

declare function MultiCheckboxFacet({ className, label, onMoreClick, onRemove, onSelect, options, showMore, showSearch, onSearch, searchPlaceholder }: FacetViewProps): React$1.JSX.Element;

declare function BooleanFacet({ className, label, options, onChange, onRemove }: FacetViewProps): React$1.JSX.Element;

declare function SingleSelectFacet({ className, label, onChange, options }: FacetViewProps): React$1.JSX.Element;

declare function SingleLinksFacet({ className, label, onRemove, onSelect, options }: FacetViewProps): React$1.JSX.Element;

interface LayoutProps {
    className?: string;
    children?: React$1.ReactNode;
    header?: React$1.ReactNode;
    bodyContent?: React$1.ReactNode;
    bodyFooter?: React$1.ReactNode;
    bodyHeader?: React$1.ReactNode;
    sideContent?: React$1.ReactNode;
}
declare function Layout({ className, children, header, bodyContent, bodyFooter, bodyHeader, sideContent }: LayoutProps): React$1.JSX.Element;

declare function getFilterValueDisplay(filterValue: any): string;

declare function appendClassName(baseClassName?: string | string[] | undefined, newClassName?: string | string[] | undefined): string;

/**
 *
 * @param {URL} URLParser URL interface provided by browser https://developer.mozilla.org/en-US/docs/Web/API/URL
 * @param {String} currentLocation String representation of the browser's current location
 */
declare function getUrlSanitizer(URLParser: typeof URL, currentLocation: string): (url: any) => any;

declare function getRaw(object: any): any;
declare function getEscapedField(maybeObject: any): any;
declare function formatResult(result: any): {};

declare const index_appendClassName: typeof appendClassName;
declare const index_formatResult: typeof formatResult;
declare const index_getEscapedField: typeof getEscapedField;
declare const index_getFilterValueDisplay: typeof getFilterValueDisplay;
declare const index_getRaw: typeof getRaw;
declare const index_getUrlSanitizer: typeof getUrlSanitizer;
declare namespace index {
  export { index_appendClassName as appendClassName, index_formatResult as formatResult, index_getEscapedField as getEscapedField, index_getFilterValueDisplay as getFilterValueDisplay, index_getRaw as getRaw, index_getUrlSanitizer as getUrlSanitizer };
}

export { Autocomplete, type BaseContainerProps, BooleanFacet, ErrorBoundary, type ErrorBoundaryViewProps, type FacetContainerProps, type FacetViewProps, Facets, type InputViewProps, Layout, MultiCheckboxFacet, Paging, type PagingContainerContext, type PagingContainerProps, PagingInfo, type PagingInfoContainerContext, type PagingInfoContainerProps, type PagingInfoViewProps, type PagingViewProps, type Rename, Result, type ResultContainerProps, type ResultViewProps, Results, type ResultsContainerProps, ResultsPerPage, type ResultsPerPageContainerContext, type ResultsPerPageContainerProps, type ResultsPerPageViewProps, type ResultsViewProps, SearchBox, type SearchBoxAutocompleteViewProps, type SearchBoxContainerContext, type SearchBoxContainerProps, type SearchBoxViewProps, SingleLinksFacet, SingleSelectFacet, Sorting, type SortingContainerProps, type SortingViewProps, index as ViewHelpers };
